import os
import simplejson as json
from operator import itemgetter

from dateutil.parser import parse

from django.contrib.auth import logout
from django.contrib.auth.decorators import login_required
from django.conf import settings
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext

from django_oauth_client.decorators import oauth_token_required
from django_oauth_client.utils import get_client


def index(request):
    return render_to_response(
        'index.html', context_instance=RequestContext(request))


def log_out(request):
    """Logout the User"""
    logout(request)
    return HttpResponseRedirect(settings.OPENID_SSO_LOGOUT_URL)

@login_required
@oauth_token_required('ubuntuone')
def public_files(request):
    # Make an authenticated API request.
    client = get_client(request.user, 'ubuntuone')
    client.disable_ssl_certificate_validation = True
    response, content = client.request(
        'https://staging.one.ubuntu.com/api/file_storage/v1/public_files')

    try:
        files = json.loads(content)
    except ValueError:
        # handle bad json
        raise

    files.sort(key=itemgetter(u'when_changed'), reverse=True)

    for f in files:
        path = f['resource_path'].lstrip('/')
        f['dirname'] = os.path.dirname(path)
        f['basename'] = os.path.basename(path)
        f['when_changed'] = parse(f['when_changed'])

    return render_to_response(
        'u1account.html', {'files': files},
        context_instance=RequestContext(request))
